@@ -2,23 +2,18 @@
 
 from __future__ import absolute_import, division, print_function, unicode_literals
 
-from django import template
-from django.contrib.admin.options import csrf_protect_m, ModelAdmin
-from django.contrib.admin.views.main import ChangeList, SEARCH_VAR
+from django.contrib.admin.options import ModelAdmin, csrf_protect_m
+from django.contrib.admin.views.main import SEARCH_VAR, ChangeList
 from django.core.exceptions import PermissionDenied
 from django.core.paginator import InvalidPage, Paginator
-from django.shortcuts import render_to_response
+from django.shortcuts import render
+from django.utils.encoding import force_text
 from django.utils.translation import ungettext
 
 from haystack import connections
 from haystack.query import SearchQuerySet
 from haystack.utils import get_model_ct_tuple
 
-try:
-    from django.utils.encoding import force_text
-except ImportError:
-    from django.utils.encoding import force_unicode as force_text
-
 
 def list_max_show_all(changelist):
     """
@@ -150,13 +145,13 @@ class SearchModelAdminMixin(object):
             'actions_selection_counter': getattr(self, 'actions_selection_counter', 0),
         }
         context.update(extra_context or {})
-        context_instance = template.RequestContext(request, current_app=self.admin_site.name)
+        request.current_app = self.admin_site.name
         app_name, model_name = get_model_ct_tuple(self.model)
-        return render_to_response(self.change_list_template or [
+        return render(request, self.change_list_template or [
             'admin/%s/%s/change_list.html' % (app_name, model_name),
             'admin/%s/change_list.html' % app_name,
             'admin/change_list.html'
-        ], context, context_instance=context_instance)
+        ], context)
 
 
 class SearchModelAdmin(SearchModelAdminMixin, ModelAdmin):
