@@ -15,9 +15,14 @@ class SimpleMockSearchIndex(indexes.SearchIndex, indexes.Indexable):
     def get_model(self):
         return MockModel
 
+
 class SimpleMockScoreIndex(indexes.SearchIndex, indexes.Indexable):
     text = indexes.CharField(document=True, use_template=True)
     score = indexes.CharField(model_attr='score')
 
     def get_model(self):
         return ScoreMockModel
+
+
+class SimpleMockUUIDModelIndex(indexes.SearchIndex, indexes.Indexable):
+    text = indexes.CharField(document=True, model_attr="characteristics")
